<?php

namespace core\config\class\core;

/**
 * Log configuration
 */
readonly class LogConfiguration extends \core\config\Configuration
{
	/**
	 * tags used to determine if an event should be logged
	 *
	 * A tags logging system is used here. Which mean an event is
	 * associated to multiple tags. For example, an event can be
	 * associated to the tags ['core', 'fatal', 'page_loading', 'user'].
	 *
	 * This allows the administrator to setup a list of tags to "watch",
	 * and only event which use these tags will be logged. Allowing a fine
	 * grained logging.
	 *
	 * Default is empty array
	 *
	 * @var \core\log\TagsType
	 */
	protected \core\log\TagsType $tags;

	/**
	 * client used to log events
	 *
	 * The parameters is a children of the abstract class
	 * \core\config\class\log\Client
	 *
	 * @var \core\config\class\core\log\ClientConfiguration
	 */
	protected \core\config\class\core\log\ClientConfiguration $client;

	/**
	 * formatting settings for log event
	 *
	 * @var \core\config\class\core\log\FormatConfiguration
	 */
	protected \core\config\class\log\FormatConfiguration $format;
}

?>
