<?php

namespace core\config\class\core\log;

/**
 * Log format configuration
 */
readonly class FormatConfiguration extends \core\config\Configuration
{
	/**
	 * message format string
	 *
	 * String to format event message, using substitution:
	 *   - {tags} will be replaced by a list of tags separated with commas
	 *   - {date} will be replaced by the date, using the format string
	 *     specified in \core\config\class\core\log\FormatConfiguration->date
	 *   - {message} will be replaced by the message content
	 *   - {file} will be replaced by the path of the file where the event
	 *     was created
	 *   - {line} will be replaced by the line number where the event was
	 *     created
	 *
	 * Default is '[{tags}] - {date}: {message} in {file} at line {line}'
	 *
	 * @param \string
	 */
	protected string $message;

	/**
	 * date format string
	 *
	 * Used if '{date}' is in \core\config\class\core\log\FormatConfiguration->message
	 * This string will indicate how the event date will be displayed in
	 * the logs. It use php's datetime format described here:
	 * https://www.php.net/manual/en/datetime.format.php
	 *
	 * Default is 'Y-m-d H:i:s'
	 *
	 * @param \string
	 */
	protected string $date;
}

?>
