<?php

namespace core\config\class\core\log\client;

/**
 * Configuration factory
 */
class ConfigurationFactory implements \core\config\ConfigurationFactory
{
	/**
	 * Build the client configuration corresponding to the current
	 * configuration array
	 *
	 * @param \array $configuration Array containing raw configuration
	 *
	 * @return \core\config\class\core\log\ClientConfiguration Client configuration
	 */
	public static function build(array $configuration) : \core\config\class\core\log\ClientConfiguration
	{
		if (!\in_array('name', \array_keys($configuration)))
		{
			$configuration['name'] = 'File'; # default configuration
		}
		$configuration['name'] = \ucwords($configuration['name']);
		$configuration['name'] = \str_replace(' ', '', $configuration['name']);

		$vanilla = '\\core\\config\\class\\core\\log\\client\\' . $configuration['name'];

		if (\in_array($configuration['name'], \core\log\StreamFactory::AVAILABLE_CLIENTS))
		{
			return new $vanilla($configuration);
		}
		$plugin = \core\plugin\PluginManager::fetch_class($vanilla);

		if (!\is_null($plugin) && \class_exists($plugin))
		{
			return new $plugin($configuration);
		}

		throw new \core\config\ConfigException(\core\substitute(
			_('unknown configuration for client {client}'),
			array('client' => $configuration['name']),
		), 1);
	}
}

?>
