<?php

namespace core\log;

/**
 * Base class for logging tag
 */
abstract class Tag
{
	/**
	 * Name of the tag
	 *
	 * @var \string
	 */
	protected string $name;

	/**
	 * Children tags
	 *
	 * @var \array[\core\log\Tag]
	 */
	protected array $children;

	/**
	 * Generate safe id for general purpose (only [A-Z][a-Z]-_ chars)
	 *
	 * Replace whitespace character and non base latin character to "_".
	 * Keep [A-Z][a-z]- chars as it is
	 *
	 * @return string Safe identifier
	 */
	public function generate_id() : string
	{
		return \preg_replace(
			'/[^a-zA-Z-]/gm',
			'_',
			\mb_convert_encoding(
				$this->__tostring(),
				'ASCII',
				'UTF-8',
			),
		);
	}

	public function __toString() : string
	{
		return $this->name;
	}
}

?>
